@@ -14,8 +14,8 @@ set -e
 # sh 3.4/debian/orig-tar.sh RELEASE_34 rc1
 
 SVN_BASE_URL=http://llvm.org/svn/llvm-project/
-MAJOR_VERSION=3.8
-CURRENT_VERSION=3.8 # Should be changed to 3.5.1 later
+MAJOR_VERSION=3.9
+CURRENT_VERSION=3.9 # Should be changed to 3.5.1 later
 
 if test -n "$1"; then
 # http://llvm.org/svn/llvm-project/{cfe,llvm,compiler-rt,...}/branches/google/stable/
@@ -113,7 +113,7 @@ rm -rf $COMPILER_RT_TARGET
 # Polly
 POLLY_TARGET=polly_$VERSION
 $SVN_CMD $(get_svn_url polly $BRANCH $TAG) $POLLY_TARGET
-rm -rf $POLLY_TARGET/www
+rm -rf $POLLY_TARGET/www $POLLY_TARGET/autoconf/config.sub $POLLY_TARGET/autoconf/config.guess
 tar jcvf $FULL_VERSION.orig-polly.tar.bz2 $POLLY_TARGET
 rm -rf $POLLY_TARGET
 
